==> com.liferay.dynamic.data.mapping.form.renderer-3.0.69.jar: META-INF/resources/form.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@3.0.69/form.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './form.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _form = _interopRequireDefault(require("./form.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var FormTemplates = [];

  if (!window.ddm) {
    window.ddm = {};
  }

  for (var template in _form["default"]) {
    if (template !== 'templates') {
      var C =
      /*#__PURE__*/
      function (_Component) {
        _inherits(C, _Component);

        function C() {
          _classCallCheck(this, C);

          return _possibleConstructorReturn(this, _getPrototypeOf(C).apply(this, arguments));
        }

        return C;
      }(_metalComponent["default"]);

      _metalSoy["default"].register(C, _form["default"], template);

      FormTemplates.push({
        component: C,
        key: template
      });
      window.ddm[template] = C;
    }
  }

  window.MetalComponent = _metalComponent["default"];
  var _default = FormTemplates;
  exports["default"] = _default;
  //# sourceMappingURL=form.es.js.map
});
//# sourceMappingURL=form.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-4.0.3.jar: META-INF/resources/form.es.js <==
"use strict";

Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.3/form.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './form.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _form = _interopRequireDefault(require("./form.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var FormTemplates = [];

  if (!window.ddm) {
    window.ddm = {};
  }

  for (var template in _form.default) {
    if (template !== 'templates') {
      var C =
      /*#__PURE__*/
      function (_Component) {
        _inherits(C, _Component);

        function C() {
          _classCallCheck(this, C);

          return _possibleConstructorReturn(this, _getPrototypeOf(C).apply(this, arguments));
        }

        return C;
      }(_metalComponent.default);

      _metalSoy.default.register(C, _form.default, template);

      FormTemplates.push({
        component: C,
        key: template
      });
      window.ddm[template] = C;
    }
  }

  window.MetalComponent = _metalComponent.default;
  var _default = FormTemplates;
  exports.default = _default;
  //# sourceMappingURL=form.es.js.map
});
//# sourceMappingURL=form.es.js.map
